@@ -33,9 +33,10 @@
 #  define GRANTLEE_TEXTDOCUMENT_DEPRECATED_NO_EXPORT GRANTLEE_TEXTDOCUMENT_NO_EXPORT GRANTLEE_TEXTDOCUMENT_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define GRANTLEE_TEXTDOCUMENT_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef GRANTLEE_TEXTDOCUMENT_NO_DEPRECATED
+#    define GRANTLEE_TEXTDOCUMENT_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
